Mopidy-InternetArchive
========================================================================

Mopidy-InternetArchive is a Mopidy_ extension for playing music from
the `Internet Archive`_.

This extension lets you search for and stream recordings ranging from
`alternative news programming`_, to `Grateful Dead concerts`_, to `Old
Time Radio shows`_, to `book and poetry readings`_, to `original
music`_ uploaded by Internet Archive users.  It also gives you access
to a vast number of high-quality live recordings from the `Live Music
Archive`_, and thousands of free audiobooks from the LibriVox_
collection.

For more information and installation instructions, please see
Mopidy-InternetArchive's online documentation_.


Project Resources
------------------------------------------------------------------------

.. image:: https://img.shields.io/pypi/v/Mopidy-InternetArchive.svg?style=flat
    :target: https://pypi.python.org/pypi/Mopidy-InternetArchive/
    :alt: Latest PyPI version

.. image:: http://img.shields.io/travis/tkem/mopidy-internetarchive/master.svg?style=flat
    :target: https://travis-ci.org/tkem/mopidy-internetarchive/
    :alt: Travis CI build status

.. image:: http://img.shields.io/coveralls/tkem/mopidy-internetarchive/master.svg?style=flat
   :target: https://coveralls.io/r/tkem/mopidy-internetarchive/
   :alt: Test coverage

.. image:: https://readthedocs.org/projects/mopidy-internetarchive/badge/?version=latest&style=flat
   :target: http://mopidy-internetarchive.readthedocs.org/en/latest/
   :alt: Documentation Status

- `Issue Tracker`_
- `Source Code`_
- `Change Log`_


License
------------------------------------------------------------------------

Copyright (c) 2014-2017 Thomas Kemmer.

Licensed under the `Apache License, Version 2.0`_.


.. _Mopidy: http://www.mopidy.com/
.. _Internet Archive: http://archive.org
.. _alternative news programming: https://archive.org/details/audio_news
.. _Grateful Dead concerts: https://archive.org/details/GratefulDead
.. _Old Time Radio shows: https://archive.org/details/radioprograms
.. _book and poetry readings: https://archive.org/details/audio_bookspoetry
.. _original music: https://archive.org/details/opensource_audio
.. _Live Music Archive: https://archive.org/details/etree
.. _LibriVox: https://archive.org/details/librivoxaudio

.. _Documentation: http://mopidy-internetarchive.readthedocs.org/en/latest/
.. _Issue Tracker: https://github.com/tkem/mopidy-internetarchive/issues/
.. _Source Code: https://github.com/tkem/mopidy-internetarchive/
.. _Change Log: https://github.com/tkem/mopidy-internetarchive/blob/master/CHANGES.rst

.. _Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0
